@@ -1,19 +1,20 @@
 #!/bin/bash
 # de-rpm.sh: Unpack an 'rpm' archive
 
-E_NO_ARGS=65
+: ${1?"Usage: `basename $0` target-file"}
+# Must specify 'rpm' archive name as an argument.
+
+
 TEMPFILE=$$.cpio                         # Tempfile with "unique" name.
                                          # $$ is process ID of script.
 
-if [ -z "$1" ] 
-then
-  echo "Usage: `basename $0` filename"
-exit $E_NO_ARGS
-fi
-
-
 rpm2cpio < $1 > $TEMPFILE                # Converts rpm archive into cpio archive.
 cpio --make-directories -F $TEMPFILE -i  # Unpacks cpio archive.
 rm -f $TEMPFILE                          # Deletes cpio archive.
 
 exit 0
+
+#  Exercise:
+#  Add check for whether 1) "target-file" exists and
+#+                       2) it is really an rpm archive.
+#  Hint:                    parse output of 'file' command.
