@@ -1,4 +1,5 @@
 #!/bin/bash
+# Naked variables
 
 echo
 
@@ -7,16 +8,16 @@ echo
 
 # Assignment
 a=879
-echo "The value of \"a\" is $a"
+echo "The value of \"a\" is $a."
 
 # Assignment using 'let'
 let a=16+5
-echo "The value of \"a\" is now $a"
+echo "The value of \"a\" is now $a."
 
 echo
 
 # In a 'for' loop (really, a type of disguised assignment)
-echo -n "The values of \"a\" in the loop are "
+echo -n "Values of \"a\" in the loop are: "
 for a in 7 8 9 11
 do
   echo -n "$a "
@@ -28,7 +29,7 @@ echo
 # In a 'read' statement (also a type of assignment)
 echo -n "Enter \"a\" "
 read a
-echo "The value of \"a\" is now $a"
+echo "The value of \"a\" is now $a."
 
 echo
 
