@@ -3,14 +3,21 @@
 
 echo
 
+echo "Subshell level OUTSIDE subshell = $BASH_SUBSHELL"
+# Bash, version 3, adds the new         $BASH_SUBSELL variable.
+echo
+
 outer_variable=Outer
 
 (
+echo "Subshell level INSIDE subshell = $BASH_SUBSHELL"
 inner_variable=Inner
 echo "From subshell, \"inner_variable\" = $inner_variable"
 echo "From subshell, \"outer\" = $outer_variable"
 )
 
+echo
+echo "Subshell level OUTSIDE subshell = $BASH_SUBSHELL"
 echo
 
 if [ -z "$inner_variable" ]
